# Bad Word Obfuscator
 This code obfuscates naughty words by using a rot13 cipher to prevent them from being directly visible.

## Install Instructions

### PIP Install Instructions

* To install via pip use:<br>
    `pip install BadWordObfuscator`

To see package on **pypi:** https://pypi.org/project/BadWordObfuscator/

### Manual Build & Install

1. Build wheel with:<br>
    `python setup.py bdist_wheel`
2. Install wheel with:<br>
    `pip install {/path/to/wheelfile.whl}`